Within the ppg2 source there's a folder ['examples'](https://github.com/TyberiusPrime/pypipegraph2/tree/main/examples), 
which unfortunatly right now are not useful examples for the user,
but debug helpers that exercise some of the interesting edge cases.


